@@ -1,3 +1,4 @@
+from django.conf import settings
 from django.contrib.auth.models import User
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
@@ -6,7 +7,8 @@ from oauth.oauth import OAuthToken
 import simplejson
 import twitter
 
-from django_oauth_twitter.utils import get_user_info, TwitterApi
+from django_oauth_twitter.cache import DjangoCachedApi
+from django_oauth_twitter.utils import fail_whale, get_user_info, TwitterApi
 
 
 class UserAlreadyLinked(Exception):
@@ -101,8 +103,11 @@ class TwitterUser(models.Model):
             return True
 
     def api(self):
+        cache_timeout = getattr(settings, 'DJANGO_OAUTH_TWITTER_CACHE_TIMEOUT',
+                                60)
         if self._api is None:
-            self._api = TwitterApi(self.access_token)
+            self._api = DjangoCachedApi(api=TwitterApi(self.access_token),
+                                        cache_timeout=cache_timeout)
         return self._api
 
     def userinfo(self):
@@ -115,7 +120,7 @@ class TwitterUser(models.Model):
 
     def update_userinfo(self, userinfo=None):
         if userinfo is None:
-            userinfo = self.api().GetUserInfo()
+            userinfo = fail_whale(self.api().GetUserInfo)()
         userinfo_json = userinfo.AsJsonString()
         if self.userinfo_json != userinfo_json:
             self.userinfo_json = userinfo_json
@@ -132,14 +137,14 @@ class TwitterUser(models.Model):
 
         If `user` is None, default to this User.
         """
-        friends = self.api().GetFriends(user=user, cursor=None)
+        friends = fail_whale(self.api().GetFriends)(user=user, cursor=None)
         return self.__class__.objects.filter(
             twitter_id__in=[f.id for f in friends]
         )
 
     def get_site_followers(self):
         """Returns a queryset of Users who are Twitter followers of this User."""
-        followers = self.api().GetFollowers(cursor=None)
+        followers = fail_whale(self.api().GetFollowers)(cursor=None)
         return self.__class__.objects.filter(
             twitter_id__in=[f.id for f in followers]
         )
