@@ -91,6 +91,12 @@ class OAuthTwitterTest(TestCase):
     def tearDown(self):
         settings.TEMPLATE_DIRS = self.old_template_dirs
 
+    def test_association_anonymous(self):
+        # Ensure we need a login.
+        response = self.client.get(reverse(oauthtwitter.associate))
+        self.assertEqual(response['Location'],
+                         'http://testserver%s' % settings.LOGIN_URL)
+
     def test_association_user_add(self):
         # User adds association.
         self.assertRaises(TwitterUser.DoesNotExist,
@@ -163,7 +169,8 @@ class OAuthTwitterTest(TestCase):
             response = self.client.get(reverse(oauthtwitter.callback),
                                        {'oauth_token': TOKEN.key})
             self.assertEqual(response['Location'],
-                             'http://testserver/twitter/associate/')
+                             'http://testserver/twitter/associate/'
+                             '?user=twitter&error=user_already_linked')
 
     def test_association_associated_remove(self):
         # Associated removes association.
